"""
backend_identity_index_entry automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union


# Represents a concrete identity class
class BackendIdentityIndexEntry(BaseModel):
    name: Optional[str] = Field(default=None, alias="name")
    class_: Optional[str] = Field(default=None, alias="class")
    pass





"""
backend_firewall_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union
from .common_collection import CommonCollection
from .backend_firewall import BackendFirewall


# A paginated collection of firewall objects
class BackendFirewallCollection(CommonCollection[BackendFirewall]):
    pass





"""
backend_connection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union
from .backend_connection_config import BackendConnectionConfig
from .common_metadata import CommonMetadata


# This object represents a connection to an external system like i.e. a database, message-queue or client-sdk
class BackendConnection(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    class_: Optional[str] = Field(default=None, alias="class")
    oauth_: Optional[bool] = Field(default=None, alias="oauth2")
    config: Optional[BackendConnectionConfig] = Field(default=None, alias="config")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    pass





"""
consumer_user_plan automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union


class ConsumerUserPlan(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    price: Optional[int] = Field(default=None, alias="price")
    points: Optional[int] = Field(default=None, alias="points")
    period: Optional[int] = Field(default=None, alias="period")
    pass





"""
common_form_container automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union
from .common_form_element import CommonFormElement
from .common_form_element_input import CommonFormElementInput
from .common_form_element_select import CommonFormElementSelect
from .common_form_element_tag import CommonFormElementTag
from .common_form_element_text_area import CommonFormElementTextArea


class CommonFormContainer(BaseModel):
    element: Optional[List[Annotated[Union[Annotated[CommonFormElementInput, Tag('http://fusio-project.org/ns/2015/form/input')], Annotated[CommonFormElementSelect, Tag('http://fusio-project.org/ns/2015/form/select')], Annotated[CommonFormElementTag, Tag('http://fusio-project.org/ns/2015/form/tag')], Annotated[CommonFormElementTextArea, Tag('http://fusio-project.org/ns/2015/form/textarea')]], Field(discriminator='type')]]] = Field(default=None, alias="element")
    pass





"""
backend_action automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union
from .backend_action_config import BackendActionConfig
from .common_metadata import CommonMetadata


# This object represents the business logic which can be executed either through an operation or cronjob
class BackendAction(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    status: Optional[int] = Field(default=None, alias="status")
    name: Optional[str] = Field(default=None, alias="name")
    class_: Optional[str] = Field(default=None, alias="class")
    async_: Optional[bool] = Field(default=None, alias="async")
    config: Optional[BackendActionConfig] = Field(default=None, alias="config")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    pass





"""
backend_backup_export automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union


# Export of the complete system configuration
class BackendBackupExport(BaseModel):
    export: Optional[str] = Field(default=None, alias="export")
    pass





"""
backend_rate automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union
from .backend_rate_allocation import BackendRateAllocation
from .common_metadata import CommonMetadata


# This object represents a rate limitation, which allows to limit the requests which a user can send
class BackendRate(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    priority: Optional[int] = Field(default=None, alias="priority")
    name: Optional[str] = Field(default=None, alias="name")
    rate_limit: Optional[int] = Field(default=None, alias="rateLimit")
    timespan: Optional[str] = Field(default=None, alias="timespan")
    allocation: Optional[List[BackendRateAllocation]] = Field(default=None, alias="allocation")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    pass


